pub struct GroupResource<'a> { /* private fields */ }Expand description
Group resources, Icons and Cursors.
Implementations
Sourceimpl<'a> GroupResource<'a>
impl<'a> GroupResource<'a>
Sourcepub fn new(
resources: Resources<'a>,
bytes: &'a [u8],
) -> Result<GroupResource<'a>, Error>
pub fn new( resources: Resources<'a>, bytes: &'a [u8], ) -> Result<GroupResource<'a>, Error>
Parses the GroupResource from the byte slice.
The pixel data of the group resource is stored in separate data entries, requiring the resources to access.
Sourcepub fn header(&self) -> &'a GRPICONDIR
pub fn header(&self) -> &'a GRPICONDIR
Gets the Group header.
Sourcepub fn entries(&self) -> &'a [GRPICONDIRENTRY]
pub fn entries(&self) -> &'a [GRPICONDIRENTRY]
Gets the Group entries.
Sourcepub fn ty(&self) -> ResourceType
pub fn ty(&self) -> ResourceType
Gets the Group resource type.